==> vkd3d-docs-1.17-2-x86_64.pkg.tar.zst: usr/share/doc/vkd3d/vkd3d_8h.js <==
var vkd3d_8h =
[
    [ "vkd3d_instance_create_info", "structvkd3d__instance__create__info.html", "structvkd3d__instance__create__info" ],
    [ "vkd3d_optional_instance_extensions_info", "structvkd3d__optional__instance__extensions__info.html", "structvkd3d__optional__instance__extensions__info" ],
    [ "vkd3d_application_info", "structvkd3d__application__info.html", "structvkd3d__application__info" ],
    [ "vkd3d_host_time_domain_info", "structvkd3d__host__time__domain__info.html", "structvkd3d__host__time__domain__info" ],
    [ "vkd3d_device_create_info", "structvkd3d__device__create__info.html", "structvkd3d__device__create__info" ],
    [ "vkd3d_optional_device_extensions_info", "structvkd3d__optional__device__extensions__info.html", "structvkd3d__optional__device__extensions__info" ],
    [ "vkd3d_image_resource_create_info", "structvkd3d__image__resource__create__info.html", "structvkd3d__image__resource__create__info" ],
    [ "VKD3D_RESOURCE_INITIAL_STATE_TRANSITION", "vkd3d_8h.html#aee229fb91201c3aca4aa07317a1f021b", null ],
    [ "VKD3D_RESOURCE_PRESENT_STATE_TRANSITION", "vkd3d_8h.html#ad05bbb95fdfabfe61e562326c945099e", null ],
    [ "PFN_vkd3d_queue_signal_on_cpu", "vkd3d_8h.html#a403fe51b8d382a83729ed3d412e2f21e", null ],
    [ "PFN_vkd3d_set_log_callback", "vkd3d_8h.html#aa5eaf466c0a3601dcbd1889426b2a6f5", null ],
    [ "vkd3d_structure_type", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cc", [
      [ "VKD3D_STRUCTURE_TYPE_INSTANCE_CREATE_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cca9af05b5a30613652a441e277788f7c52", null ],
      [ "VKD3D_STRUCTURE_TYPE_DEVICE_CREATE_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccab022d10440b1a9a82ab6255b30a55d31", null ],
      [ "VKD3D_STRUCTURE_TYPE_IMAGE_RESOURCE_CREATE_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccaebfda1cc1da0f91bbc312a2b79be3b3d", null ],
      [ "VKD3D_STRUCTURE_TYPE_OPTIONAL_INSTANCE_EXTENSIONS_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cca5fb0979841544732f40c795e441cdd1e", null ],
      [ "VKD3D_STRUCTURE_TYPE_OPTIONAL_DEVICE_EXTENSIONS_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccad5aacdbc7e6fa79d65475d8b7cd11858", null ],
      [ "VKD3D_STRUCTURE_TYPE_APPLICATION_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccaf43d44cbc1951cb708446c69dfab98c7", null ],
      [ "VKD3D_STRUCTURE_TYPE_HOST_TIME_DOMAIN_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cca399b0dfe2d6bb2353746552811cf3274", null ],
      [ "VKD3D_FORCE_32_BIT_ENUM", "vkd3d_8h.html#ab5463cd94e57de14087fa17761e35e98", null ]
    ] ],
    [ "vkd3d_acquire_vk_queue", "vkd3d_8h.html#a3d2e348315c63569cd064cf5c5931125", null ],
    [ "vkd3d_queue_signal_on_cpu", "vkd3d_8h.html#a406765d1b1a113be328d4a6729ff8d78", null ],
    [ "vkd3d_release_vk_queue", "vkd3d_8h.html#a9e1e3ce23cffb4b43b484279a602888a", null ],
    [ "vkd3d_set_log_callback", "vkd3d_8h.html#a66a1f1fd163cde3a5beafd0a34cc3550", null ]
];

==> vkd3d-docs-1.18-1-x86_64.pkg.tar.zst: usr/share/doc/vkd3d/vkd3d_8h.js <==
var vkd3d_8h =
[
    [ "vkd3d_instance_create_info", "structvkd3d__instance__create__info.html", "structvkd3d__instance__create__info" ],
    [ "vkd3d_optional_instance_extensions_info", "structvkd3d__optional__instance__extensions__info.html", "structvkd3d__optional__instance__extensions__info" ],
    [ "vkd3d_application_info", "structvkd3d__application__info.html", "structvkd3d__application__info" ],
    [ "vkd3d_host_time_domain_info", "structvkd3d__host__time__domain__info.html", "structvkd3d__host__time__domain__info" ],
    [ "vkd3d_device_create_info", "structvkd3d__device__create__info.html", "structvkd3d__device__create__info" ],
    [ "vkd3d_optional_device_extensions_info", "structvkd3d__optional__device__extensions__info.html", "structvkd3d__optional__device__extensions__info" ],
    [ "vkd3d_image_resource_create_info", "structvkd3d__image__resource__create__info.html", "structvkd3d__image__resource__create__info" ],
    [ "VKD3D_RESOURCE_INITIAL_STATE_TRANSITION", "vkd3d_8h.html#aee229fb91201c3aca4aa07317a1f021b", null ],
    [ "VKD3D_RESOURCE_PRESENT_STATE_TRANSITION", "vkd3d_8h.html#ad05bbb95fdfabfe61e562326c945099e", null ],
    [ "PFN_vkd3d_queue_signal_on_cpu", "vkd3d_8h.html#a403fe51b8d382a83729ed3d412e2f21e", null ],
    [ "PFN_vkd3d_set_log_callback", "vkd3d_8h.html#aa5eaf466c0a3601dcbd1889426b2a6f5", null ],
    [ "vkd3d_structure_type", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cc", [
      [ "VKD3D_STRUCTURE_TYPE_INSTANCE_CREATE_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cca9af05b5a30613652a441e277788f7c52", null ],
      [ "VKD3D_STRUCTURE_TYPE_DEVICE_CREATE_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccab022d10440b1a9a82ab6255b30a55d31", null ],
      [ "VKD3D_STRUCTURE_TYPE_IMAGE_RESOURCE_CREATE_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccaebfda1cc1da0f91bbc312a2b79be3b3d", null ],
      [ "VKD3D_STRUCTURE_TYPE_OPTIONAL_INSTANCE_EXTENSIONS_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cca5fb0979841544732f40c795e441cdd1e", null ],
      [ "VKD3D_STRUCTURE_TYPE_OPTIONAL_DEVICE_EXTENSIONS_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccad5aacdbc7e6fa79d65475d8b7cd11858", null ],
      [ "VKD3D_STRUCTURE_TYPE_APPLICATION_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8ccaf43d44cbc1951cb708446c69dfab98c7", null ],
      [ "VKD3D_STRUCTURE_TYPE_HOST_TIME_DOMAIN_INFO", "vkd3d_8h.html#a9a37a0f8630da187e4cc4e81bdd7f8cca399b0dfe2d6bb2353746552811cf3274", null ]
    ] ],
    [ "vkd3d_acquire_vk_queue", "vkd3d_8h.html#a3d2e348315c63569cd064cf5c5931125", null ],
    [ "vkd3d_queue_signal_on_cpu", "vkd3d_8h.html#a406765d1b1a113be328d4a6729ff8d78", null ],
    [ "vkd3d_release_vk_queue", "vkd3d_8h.html#a9e1e3ce23cffb4b43b484279a602888a", null ],
    [ "vkd3d_set_log_callback", "vkd3d_8h.html#a66a1f1fd163cde3a5beafd0a34cc3550", null ]
];
